@@ -14,9 +14,14 @@ FAST_API_SKILL_TEMPLATE_URL = ""
 about = {
     '__title__': 'scintillant',
     '__description__': 'Fast bot creating framework',
-    '__version__': '0.0.10',
+    '__version__': '0.0.12.16',
     '__author__': 'Niel Ketov',
     '__author_email__': 'ketov-x@yandex.ru',
     '__url__': 'https://code.tatar.ru/projects/LILIYA/repos/scintillant',
     '__license__': 'Apache 2.0'
-}  # type: ignore
+}
+
+addons_versions = {
+    '__testsuite__': 'v0.0.1',
+    '__bottle_skill_template__': ''
+}
