@@ -15,7 +15,7 @@ class SkillResponseType:
     async def from_json_response(cls, response: dict): ...
 
     @classmethod
-    async def from_request_response(cls, response): ...
+    async def from_response(cls, response): ...
 
     def serialize_json(self) -> dict: ...
 
@@ -23,7 +23,7 @@ class SkillResponseType:
 class SkillRequestType:
     class User:
         user_id: str
-        client_app: str
+        client: dict
         global_id: str
 
     class Update:
@@ -38,7 +38,7 @@ class SkillRequestType:
     def serialize_json(self) -> dict: ...
 
     @classmethod
-    async def from_aio_request(cls, request): ...
+    async def from_dict(cls, request): ...
 
 
 class ClientResponseType:
@@ -60,10 +60,11 @@ class ClientResponseType:
 class DialogAnswerRequestType:
     client_id: str
     client_app: str
+    client_type: str
     in_text: str or None
     in_choice: str or None
 
     @classmethod
-    async def from_aio_request(cls, request): ...
+    async def from_dict(cls, request): ...
 
     def serialize_json(self) -> dict: ...
