@@ -52,7 +52,7 @@ class ContextUpdater:
                                  "\n\n" \
                                  "Вы сгенерировали ваш первый шаблон навыка " \
                                  "и видите это сообщение потому, что не " \
-                                 "изменили ответ для шага `_initial_state`!"
+                                 "изменили ответ для шага `_initial_state_`!"
 
     @classmethod
     def statefunc(cls, func):
